=== modified file 'NEWS'
--- NEWS	2007-12-19 06:04:19 +0000
+++ NEWS	2007-12-21 06:34:27 +0000
@@ -43,6 +43,9 @@
 
   BUGFIXES:
 
+   * ``commit`` now succeeds when a checkout and its master branch share a
+     repository.  (Aaron Bentley, #177592)
+
    * Fixed Unicode encoding error in ``ignored`` when the output is
      redirected to a pipe. (Lukáš Lalinský)
 

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2007-12-01 00:20:36 +0000
+++ bzrlib/commit.py	2007-12-21 06:34:27 +0000
@@ -381,9 +381,11 @@
             # Upload revision data to the master.
             # this will propagate merged revisions too if needed.
             if self.bound_branch:
-                self._set_progress_stage("Uploading data to master branch")
-                self.master_branch.repository.fetch(self.branch.repository,
-                                                    revision_id=self.rev_id)
+                if not self.master_branch.repository.has_same_location(
+                        self.branch.repository):
+                    self._set_progress_stage("Uploading data to master branch")
+                    self.master_branch.repository.fetch(self.branch.repository,
+                        revision_id=self.rev_id)
                 # now the master has the revision data
                 # 'commit' to the master first so a timeout here causes the
                 # local branch to be out of date

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2007-11-21 22:17:02 +0000
+++ bzrlib/tests/test_commit.py	2007-12-21 06:34:27 +0000
@@ -19,6 +19,7 @@
 
 import bzrlib
 from bzrlib import (
+    bzrdir,
     errors,
     lockdir,
     osutils,
@@ -740,3 +741,11 @@
         rev = tree.branch.repository.get_revision(rev_id)
         self.assertEqual('John Doe <jdoe@example.com>',
                          rev.properties['author'])
+
+    def test_commit_with_checkout_and_branch_sharing_repo(self):
+        repo = self.make_repository('repo', shared=True)
+        # make_branch_and_tree ignores shared repos
+        branch = bzrdir.BzrDir.create_branch_convenience('repo/branch')
+        tree2 = branch.create_checkout('repo/tree2')
+        tree2.commit('message', rev_id='rev1')
+        self.assertTrue(tree2.branch.repository.has_revision('rev1'))

